==> qtjambi-xml-5.15.14-sources.jar: io/qt/xml/QDomCDATASection.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Represents an XML CDATA section</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qdomcdatasection.html">QDomCDATASection</a></p>
 */
public class QDomCDATASection extends io.qt.xml.QDomText
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcdatasection.html#QDomCDATASection">QDomCDATASection::QDomCDATASection()</a></p>
     */
    public QDomCDATASection(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomCDATASection instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcdatasection.html#QDomCDATASection-1">QDomCDATASection::QDomCDATASection(QDomCDATASection)</a></p>
     */
    public QDomCDATASection(io.qt.xml.@NonNull QDomCDATASection x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomCDATASection instance, io.qt.xml.QDomCDATASection x);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomcdatasection.html#operator-eq">QDomCDATASection::operator=(QDomCDATASection)</a></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomCDATASection arg__1){
        assign_native_cref_QDomCDATASection(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomCDATASection(long __this__nativeId, long arg__1);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QDomCDATASection(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QDomCDATASection clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomCDATASection clone_native(long __this_nativeId);
}

==> qtjambi-xml-6.5.0-sources.jar: io/qt/xml/QDomCDATASection.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Represents an XML CDATA section</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qdomcdatasection.html">QDomCDATASection</a></p>
 */
public class QDomCDATASection extends io.qt.xml.QDomText
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomcdatasection.html#QDomCDATASection">QDomCDATASection::QDomCDATASection()</a></p>
     */
    public QDomCDATASection(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomCDATASection instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomcdatasection.html#QDomCDATASection-1">QDomCDATASection::QDomCDATASection(QDomCDATASection)</a></p>
     */
    public QDomCDATASection(io.qt.xml.@NonNull QDomCDATASection x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomCDATASection instance, io.qt.xml.QDomCDATASection x);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomcdatasection.html#operator-eq">QDomCDATASection::operator=(QDomCDATASection)</a></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomCDATASection arg__1){
        assign_native_cref_QDomCDATASection(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomCDATASection(long __this__nativeId, long arg__1);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QDomCDATASection(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QDomCDATASection clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomCDATASection clone_native(long __this_nativeId);
}
